Normal | Bad | Neutral | Good | White |  |  |  |
Centered: Red with Yellow |  |
Bold | Italic | Arial | Underline | Dbl Under | Strike |  |
Boxed | Thick | Dsh Red |
Right Justified |  |
Vertical: Bottom |  |
Vertical: Center |  |
Vertical: Top |  |
Comic Sans MS Font |  |
No wrap text | Comment[1] | 2nd Comment[2] |
Wrapped text |
Shrink to fit text |
10% |
Vertical | OtherWay | SlightL | SlightR | Vrot |
Next row is hidden: |  | Next col is hidden: | HIDDEN COL |
THIS ROW IS HIDDEN |
Not hidden |
Number: | 47712.00 |
4 places: | 47712.0000 |
0 places: | 47712 |
Currency: | $47,712.00 |
Accounting: | $ 47,712.00 |
Short Date: | 8/17/2030 |
Long Date: | Saturday, August 17, 2030 |
Time: | 4:17:12 AM |
Percent: | 4771200.00% |
Fraction: | 47712 |
Scientific: | 4.77E+04 |
Scientific 3: | 4.771E+04 |
Text: | 47712 |
Zip: | 07712 |
Blue: | 47712 |
Green/Red: | 47712 |
Formula: | 47712 |
Conditional1: | 47712 |
Conditional2: | 47712 |
Conditional3: | 47712 |
Hyperlink: | Microsoft Link |  |
Image: |
Errors: | #NULL! | #REF! | #DIV/0! | #VALUE! | #NAME? |  | #NUM! | #N/A
none |
solid |  |  |  |
mediumGray |  |  |  |
darkGray |  |  |  |
lightGray |  |  |  |
darkHorizontal |  |  |  |
darkVertical |  |  |  |
darkDown |  |  |  |
darkUp |  |  |  |
darkGrid |  |  |  |
darkTrellis |  |  |  |
lightHorizontal |  |  |  |
lightVertical |  |  |  |
lightDown |  |  |  |
lightUp |  |  |  |
lightGrid |  |  |  |
lightTrellis |  |  |  |
gray125 |  |  |  |
gray0625 |  |  |  |

[1]
Joe Cool:
This is a comment!
[2]
Joe Cool:
Here is a second comment!